Method: Fancygrid::Column#selectable

Defined in:
lib/fancygrid/column.rb

#selectableObject

If true, this column is treated as a database column. SQL queries may use the columns name for SELECT statements.



30
31
32
# File 'lib/fancygrid/column.rb', line 30

def selectable
  @selectable
end